#####################
### Preliminaries ###
#####################
require(ggplot2)

##########################
### Independent t-test ###
##########################
# Loading mtcar dataset 
data(mtcars)

# Boxplot of fuel consumption using ggplot
ggplot(mtcars, aes(factor(am),mpg)) + # ggplot with the desired data
  geom_boxplot(fill='lightgreen',colour='black') + # Specifying boxplot 
  labs(x="Type of car",y="Fuel consumption (in mpg)") + # Axes labels
  scale_x_discrete("Type of car", labels = c("Automatic","Manual")) 

# Calculating the mean miles per gallon 
# for automatic and manual cars separately
aggregate(mpg ~ am,    # Splitting mpg by automatic/manual
data=mtcars, # Dataset to summarise
FUN = mean)  # Summary statistic to use

# Subsetting mtcars to extract all automatic cars
auto <- subset(mtcars, am == 0)

# Subsetting mtcars to extract all manual cars
man <- subset(mtcars, am == 1)

# Perform an independent t-test.
t.test(auto$mpg, # Fuel consumption for automatic cars
       man$mpg, # Fuel consumption for manual cars
       paired = FALSE, # Samples are independent not paired
       alternative = 'two.sided') # Say we want a two-tailed test

#####################
### Paired t-test ###
#####################
# Cholesterol after diet 1
diet1<-c(4.61, 6.42, 5.40, 5.54, 3.98, 3.82, 5.01, 4.34, 3.80, 4.56, 5.35, 3.89)

# Cholesterol after diet 2
diet2<-c(3.84, 5.57, 5.85, 4.80, 3.68, 2.96, 4.41, 3.72, 3.49, 3.84, 5.26, 3.73)

# Sample means of the two diets
mean(diet1); mean(diet2)

# Sample means of the two diets
mean(diet1 - diet2)

# Perform a paired t-test.
t.test(diet1, # Data from diet 1
       diet2, # Data from diet 2
       paired=TRUE, # Selecting that this is a paired test
       alternative="two.sided") # Selecting that we want a two-sided test

########################
### Chi-squared test ###
########################
# Frequency Table
FreqTable <- rbind(c(646,160),c(85,27),c(35,21))

# Adding row names to the dataset
rownames(FreqTable) <- c('Non-users','1–4 times','5 or more times')

# Adding column names to the dataset
colnames(FreqTable) <- c('Regular Birth Weight','Low-birth Weight')

# Printing frequency table
FreqTable

# Proportions 
prop.table(FreqTable,1)

# Perform a Chi-Squared test.
chisq.test(FreqTable)
